==> cscec5bhn-fbxt-api-3.0.0-20210811.104037-32-sources.jar: com/ejianc/business/fbxt/odd/vo/OddRedirectVO.java <==
package com.ejianc.business.fbxt.odd.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 零星用工转扣实体
 * 
 * @author generator
 * 
 */
public class OddRedirectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long infoId; // 清单主键
    private String contractId; // 转扣合同主键
    private String contractName; // 转扣合同名称
    private java.math.BigDecimal mny; // 转扣金额
    private String contractCode; // 转扣合同编号
    private String suppliername; // 转扣单位名称
    private Long oddId; // 零星用工主键
    private Integer redirectNcFlag; // nc是否结算，0-否，1-是

    public Integer getRedirectNcFlag() {
        return redirectNcFlag;
    }

    public void setRedirectNcFlag(Integer redirectNcFlag) {
        this.redirectNcFlag = redirectNcFlag;
    }

    /**
     * 清单主键
     */
    public Long getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }
    /**
     * 转扣合同主键
     */
    public String getContractId() {
        return contractId;
    }

    /**
     * 转扣合同主键
     */
    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    /**
     * 转扣合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 转扣合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 转扣金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 转扣金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 转扣合同编号
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 转扣合同编号
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    /**
     * 转扣单位名称
     */
    public String getSuppliername() {
        return suppliername;
    }

    public void setSuppliername(String suppliername) {
        this.suppliername = suppliername;
    }

    /**
     * 零星用工主键
     */
    public Long getOddId() {
        return oddId;
    }

    /**
     * 零星用工主键
     */
    public void setOddId(Long oddId) {
        this.oddId = oddId;
    }
    
}

==> cscec5bhn-fbxt-api-3.0.1-20221031.111719-10-sources.jar: com/ejianc/business/fbxt/odd/vo/OddRedirectVO.java <==
package com.ejianc.business.fbxt.odd.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 零星用工转扣实体
 * 
 * @author generator
 * 
 */
public class OddRedirectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long infoId; // 清单主键
    private String contractId; // 转扣合同主键
    private String contractName; // 转扣合同名称
    private java.math.BigDecimal mny; // 转扣金额
    private String contractCode; // 转扣合同编号
    private String suppliername; // 转扣单位名称
    private String supplierId; // 转扣单位主键
    private Long oddId; // 零星用工主键
    private Integer redirectNcFlag; // nc是否结算，0-否，1-是

    public Integer getRedirectNcFlag() {
        return redirectNcFlag;
    }

    public void setRedirectNcFlag(Integer redirectNcFlag) {
        this.redirectNcFlag = redirectNcFlag;
    }

    /**
     * 清单主键
     */
    public Long getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }
    /**
     * 转扣合同主键
     */
    public String getContractId() {
        return contractId;
    }

    /**
     * 转扣合同主键
     */
    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    /**
     * 转扣合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 转扣合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 转扣金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 转扣金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 转扣合同编号
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 转扣合同编号
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    /**
     * 转扣单位名称
     */
    public String getSuppliername() {
        return suppliername;
    }

    public void setSuppliername(String suppliername) {
        this.suppliername = suppliername;
    }

    /**
     * 零星用工主键
     */
    public Long getOddId() {
        return oddId;
    }

    /**
     * 零星用工主键
     */
    public void setOddId(Long oddId) {
        this.oddId = oddId;
    }

    /**
     * 转扣单位名称
     */
    public String getSupplierId() {
        return supplierId;
    }
    /**
     * 转扣单位名称
     */
    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }
}
